@@ -1,10 +1,10 @@
 // vim: filetype=xs
 
-static inline T(KEY) KV(FUZZY_FIND_FUNC)(KV(tree_cntr_t) * cntr, T(KEY) key, T(VALUE) * value_result){
+static inline T(KEY) KV(FUZZY_FIND_FUNC)(pTHX_ KV(tree_cntr_t) * cntr, T(KEY) key, T(VALUE) * value_result){
     KV(tree_t) * t = cntr->root;
-    T(KEY) best = K(unknown)();
+    T(KEY) best = K(unknown)(aTHX);
     while( t != (KV(tree_t)*) &nil ){
-        if( K(cmp)(t->key, key, cntr->cmp) FUZZY_FIND_CMP_RESULT ){
+        if( K(cmp)(aTHX_ t->key, key, cntr->cmp) FUZZY_FIND_CMP_RESULT ){
             best = t->key;
 #if I(VALUE) != I(void)
             *value_result = t->value;
@@ -17,11 +17,11 @@ static inline T(KEY) KV(FUZZY_FIND_FUNC)(KV(tree_cntr_t) * cntr, T(KEY) key, T(V
     return best;
 }
 
-static inline UV KV(FUZZY_COUNT_FUNC)(KV(tree_cntr_t) * cntr, T(KEY) key){
+static inline UV KV(FUZZY_COUNT_FUNC)(pTHX_ KV(tree_cntr_t) * cntr, T(KEY) key){
     KV(tree_t) * t = cntr->root;
     int count = 0;
     while( t != (KV(tree_t)*) &nil ){
-        if( K(cmp)(t->key, key, cntr->cmp) FUZZY_FIND_CMP_RESULT ){
+        if( K(cmp)(aTHX_ t->key, key, cntr->cmp) FUZZY_FIND_CMP_RESULT ){
             count += t->FUZZY_FIND_BAD_DIR->size + 1;
             t = t->FUZZY_FIND_GOOD_DIR;
         }
